@@ -7,7 +7,6 @@ from typing import Any, Optional
 from .exceptions import (
     FoldingAtHomeControlAuthenticationFailed,
     FoldingAtHomeControlConnectionFailed,
-    FoldingAtHomeControlNotConnected,
 )
 
 _LOGGER = logging.getLogger(__name__)
@@ -45,10 +44,10 @@ class SerialConnection:
         self._reader, self._writer = await asyncio.open_connection(
             self._address, self._port
         )
-        self._is_connected = True
         await self._receive_welcome_message_async()
         if self._password is not None:
             await self._authenticate_async()
+        self._is_connected = True
 
     async def _receive_welcome_message_async(self) -> None:
         """Convenience method to receive strip and log the welcome message."""
@@ -77,7 +76,7 @@ class SerialConnection:
                 _LOGGER.debug("Authentication response: %s", auth_response)
                 raise FoldingAtHomeControlAuthenticationFailed("Password is incorrect.")
             auth_response = await self.read_async()
-        _LOGGER.error(
+        _LOGGER.debug(
             "Did not receive a valid authentication response in the last %d messages.",
             MAX_AUTHENTICATION_MESSAGE_COUNT,
         )
@@ -93,8 +92,6 @@ class SerialConnection:
     async def read_async(self) -> Any:
         """Read string from the socket and return it."""
         async with self._reader_lock:
-            if not self._is_connected:
-                raise FoldingAtHomeControlNotConnected
             try:
                 self._read_future = asyncio.ensure_future(self._reader.readuntil())
                 completed, pending = await asyncio.wait(
@@ -106,7 +103,7 @@ class SerialConnection:
                         await self._read_future
                     except asyncio.CancelledError:
                         pass
-                    _LOGGER.error(
+                    _LOGGER.debug(
                         "Timeout while trying to read from %s:%d",
                         self.address,
                         self.port,
@@ -123,8 +120,6 @@ class SerialConnection:
     async def send_async(self, message: str) -> None:
         """Send data."""
         async with self._writer_lock:
-            if not self._is_connected:
-                raise FoldingAtHomeControlNotConnected
             self._writer.write(message.encode())
             await self._writer.drain()
 
